/**
 * OW2 Util
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: LifeCycleAuditReport.java 5400 2010-03-05 09:52:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.auditreport.impl;

import org.ow2.util.auditreport.impl.util.ObjectEncoder;


/**
 * An audit report for lifecycle events.
 * @author Mathieu ANCELIN
 */
public class LifeCycleAuditReport extends GenericAuditReport {

    /**
     * Serial Version UID.
     */
    private static final long serialVersionUID = 7236678193896016411L;

    /**
     * Steps of a bean's lifecycle.
     */
    public static enum STEP {
        STARTING, STARTED, STOPPING, STOPPED
    }

    /**
     * The step of the bean's lifecycle.
     */
    private STEP step = null;

    static {
        ObjectEncoder.registerField(LifeCycleAuditReport.class, "step", EncodingType.LCENUM);
    }

    /**
     * the default constructor.
     */
    public LifeCycleAuditReport() {
        super();
    }

    /**
     * the constructor of the report.
     * @param requestTimeStampParam the timestamp of the report.
     * @param beanNameParam the name of the bean.
     * @param stepParam the step of the report.
     * @param currentThreadParam the current thread.
     * @param freeMemoryBeforeParam the free memory before the event.
     * @param totalMemoryBeforeParam the total memeory before the event.
     * @param freeMemoryAfterParam the free memory after the event.
     * @param totalMemoryAfterParam the total memory after the event.
     */
    public LifeCycleAuditReport(final long requestTimeStampParam, final String beanNameParam, final STEP stepParam,
            final Thread currentThreadParam, final int freeMemoryBeforeParam, final int totalMemoryBeforeParam,
            final int freeMemoryAfterParam, final int totalMemoryAfterParam) {
        super();
        setBeanName(beanNameParam);
        setRequestTimeStamp(requestTimeStampParam);
        setMethodStackTrace(currentThreadParam.getStackTrace());
        setFreeMemoryBefore(freeMemoryBeforeParam);
        setTotalMemoryBefore(totalMemoryBeforeParam);
        setFreeMemoryAfter(freeMemoryAfterParam);
        setTotalMemoryAfter(totalMemoryAfterParam);
        this.step = stepParam;
    }

    /**
     * Return the current step of the report.
     * @return the step of the report.
     */
    public STEP getStep() {
        return this.step;
    }

    /**
     * Set the step of this report.
     * @param theStep the step of this report.
     */
    public void setStep(final STEP theStep) {
        this.step = theStep;
    }
}
